package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````-!D!`#0```!PD0````0`!30`(``)
M`"@`'``;``$``'#4A0``U(4!`-2%`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0#@A0``X(4```4```````$`
M`0```-B-``#8C0(`V(T"`#@"``!@$@``!@```````0`"````Y(T``.2-`@#D
MC0(`$`$``!`!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DV(T`
M`-B-`@#8C0(`*`(``"@"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`:%I>3`\=O"17:"8\QM?^9J6L.\8$
M````$`````$```!'3E4```````,````"`````````&$````$````(`````H`
M``"H$A```D01(``"0`!6`'`8@@``,`@`$!$``!`"`"@`````````2`(@"@`*
M``2$`JA`"`5@80"$"#Y"/)<``0`()%B`!(E@#)-X"4)*0$0`0``!`4,)`$"`
MC,"$```0D!"#"0`(`1"`@$!`P@F`+$"8`D$`(,`@!`D`D``D#I-"0`0`````
M````!0````8````(``````````````````````````D````+````#`````X`
M```/````$````!(````5`````````````````````````!<````:````&P``
M`!\````@````(0```"(`````````(P```"4````I`````````"L`````````
M`````"P````M````+@```"\`````````,P```#0````V````-P``````````
M````.````#L````\`````````#T````^````0````$(```!%`````````$8`
M`````````````$<`````````2```````````````````````````````````
M`$D```!*`````````$P`````````3@```%$```!3````````````````````
M`````%0```!8````60```%H`````````6P``````````````70``````````
M````7P```&$```!B````8P```&8```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->_!*:W94/)3-/PRO]R/.((D'<-,@=+`"U634?&:OS&8N3CWVV_<`
M7@:DA_\!KS3HSDJN_\[>1RWAIP(*XT?&`<8.X#T^?I9\[#^0`FUSA<5K&IY0
MQ8D%D&&8[Q(!(_FD0OK7AYV[DQQ"1=7L4.X1XX;YG(%][1$/NI63'%N:.P]!
M39U\I]VC:UGOEWDY\HL<#!3BG@0RI86B`O89V\WCGONA;&#(.4`?,V+;[3^>
M0D3I^\/"2B)]_PJ*$%?MWI,<K4OCP-EQ6!PKT.$B&I_6O2T.L7-8.T`?P^4_
M+)@BU&BZXY)\(?_D#F]Z:?J3K01BWX4@3U>DFY;%N9Q`4!M]7S&X@@V^VE<;
MLP&+;[S02WUV;^-PF4+NH6H)0]:?(L>H(6)D!WZIG)MBT/J"["SVBVM_FGR'
M\)9\%8PES.\+4?F0=8(-0V9+$#RM.0T7ZEKQIIN3'*/@^TE7DEI2_=+O#V[%
MWQ]\D!#I+=_^2"[%F[;)U;)Q``````````````````````$`````````````
M`"`````=```````````````@````+```````````````(````-("````````
M`````!(```"R`0`````````````2````0`(`````````````$@```!T"````
M`````````!(```#S`P```)`"```````@`!<`;`$`````````````$@```!8"
M`````````````!(```!<`0``?!0!```````2````>`,``!"0`@``````$``8
M`-D!`````````````!(```#[`0`````````````2````,P0```R0`@`$````
M$0`7`(,"`````````````!(```"K!```C#(!`%0"```2``T`S0,``)@D`0`D
M````$@`-`-D"`````````````!(```#A`0`````````````2````E`(`````
M````````$@```+4#```XH`(``````!``&`"8`P`````````````2````V0,`
M`#`K`0!<!P``$@`-``T$``!T(0$`T````!(`#0#``P``<"0!`"@````2``T`
M"`(`````````````$@```-0!`````````````!(```!#`0`````````````2
M````<`(`````````````$@```%<$``#80P$`1`$``!(`#0#L`@``$)`"``0`
M```A`!@`E0$`````````````$@```*$!`````````````!(```#F`P``F$(!
M`$`!```2``T`,@(`````````````$@```*T#```0D`(``````!``%P!-`@``
M```````````2````8P```(P6`0``````$@```!`"`````````````!(```"D
M`@`````````````2````S@$`````````````$@```)P!`````````````!(`
M``#M`@``$)`"``0````A`!@`0@0``#B@`@``````$``8`(T"```@D`(`!```
M`!$`&`!7`P``?$4!``0````2``T`3@$`````````````$@```"H!````````
M`````!(````C!```'$4!`&`````2``T`@@0``"0J`0`,`0``$@`-`.H!````
M`````````!(```#W`P``-!D!```````2``T`@P``````````````$@```(\`
M`````````````!(```!B`@`````````````2````LP```!B0`@`!````$0`8
M`"L"`````````````!(```#^`P``G$4!``0````1``\`800``!"0`@``````
M$``8`*L"`````````````!(```##`@`````````````2````1@``````````
M````$@```,```````````````!(```!M!```0"$!`#0````2``T`\P``````
M````````$@```#T$```XH`(``````!``&`!U!```2"(!`"@"```2``T`]0(`
M````````````$@```+H!`````````````!(```"D```````````````2````
MT0```!20`@`$````$0`8`.L"```0D`(`!````!$`&``<`0`````````````2
M````.0(`````````````$@```+0#```XH`(``````!``&`"4!```A"D!`(@`
M```2``T`=```````````````$@```'L"`````````````!(```#<````````
M```````2````\0,```"0`@``````$``7`+4"`````````````!(````'`P``
MX(T"``0````1`!0`A@,```PJ`0`8````$@`-`(H!`````````````!(```!W
M`0`````````````2````Y@(``!`7`0`D`@``$@`-`/@``````````````!(`
M``"B!```'$(!`'P````2``T`FP(`````````````$@```%L"````````````
M`!(```!'`@`````````````2````@P$`````````````$@```,L"````````
M`````!(````D`@`````````````2````2@0``+PD`0#(!```$@`-`/T`````
M`````````!(````"`@`````````````2````H0,``.`T`0!8`0``$@`-`%0`
M`````````````!(````Z`0`````````````2````9P,``$0B`0`$````$@`-
M``D!```4%@$``````!(`````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE
M`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S
M`%!,7W1H<E]K97D`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T
M<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]A;&QO8P!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N
M`&QS965K-C0`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC
M;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A
M;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N
M`&UE;7-E=`!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S
M=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R
M<@!G971U:60`<F5A9&QI;FL`<W1R8VAR`')E861D:7(V-`!?7W-P<FEN=&9?
M8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?
M7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`
M;&EB<&5R;"YS;RXU+C,R`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`;&0M
M;&EN=7@M87)M:&8N<V\N,P!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?
M97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`
M<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T
M87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI
M8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E
M;G8`<VAA7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G
M`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<VAA7VEN:70`6%-?
M26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N-``````````````"``,``@`"
M``$````"`````0`"``(``0`"``$``0`"``(``@`!``(``0`!``$``@`"````
M`@`!``(``P`#``$``@`!``(````"``(``P`#``(``0`"``$```````$``0`"
M``$```````(````"``$``0`"``(```````$````!``$``@`#```````"````
M`@`!``$````"`````0`"``0``0```````0`"``$``@`"``(``@`"``(``0``
M``(``0```````0````$``0!#`P``$````"`````4:6D-```$`,$$````````
M`0`!`"D#```0````(````!1I:0T```,`P00````````!``$`.0,``!``````
M````%&EI#0```@#!!````````/R/`@`5`@``X(T"`!13```0D`(`%$D``!20
M`@`42```&)`"`!0Y```@D`(`%"X```"/`@`6!@``!(\"`!8$```(CP(`%A<`
M``R/`@`6*P``$(\"`!85```4CP(`%CX``!B/`@`66```'(\"`!9;```@CP(`
M%@L``"2/`@`67```*(\"`!9.```LCP(`%D(``#"/`@`6.```-(\"`!9?```X
MCP(`%C0``#R/`@`610``0(\"`!8.``!$CP(`%AL``$B/`@`6,```3(\"`!9*
M``!0CP(`%EH``%2/`@`650``6(\"`!8%``!<CP(`%E8``&"/`@`63P``9(\"
M`!8A``!HCP(`%ET``&R/`@`6$P``<(\"`!8Q``!TCP(`%@(``'B/`@`6!P``
M?(\"`!8<``"`CP(`%B0``(2/`@`69```B(\"`!8I``",CP(`%C8``)"/`@`6
M(@``E(\"`!92``"8CP(`%C<``)R/`@`6'0``H(\"`!9B``"DCP(`%DL``*B/
M`@`69P``K(\"`!8_``"PCP(`%F$``+2/`@`6"0``N(\"`!8F``"\CP(`%D``
M`,"/`@`6"@``Q(\"`!9>``#(CP(`%E```,R/`@`6.@``T(\"`!8G``#4CP(`
M%CT``-B/`@`61P``W(\"`!9E``#@CP(`%A```.2/`@`6#0``Z(\"`!8H``#L
MCP(`%BH``/"/`@`6'@``](\"`!84``#XCP(`%D8```A`+>E:`0#K"("]Z`3@
M+>4$X)_E#N"/X`CPON7<>@$``,:/XA?*C.+<^KSE`,:/XA?*C.+4^KSE`,:/
MXA?*C.+,^KSE`,:/XA?*C.+$^KSE`,:/XA?*C.*\^KSE`,:/XA?*C.*T^KSE
M`,:/XA?*C.*L^KSE`,:/XA?*C.*D^KSE`,:/XA?*C.*<^KSE`,:/XA?*C.*4
M^KSE`,:/XA?*C.*,^KSE`,:/XA?*C.*$^KSE`,:/XA?*C.)\^KSE`,:/XA?*
MC.)T^KSE`,:/XA?*C.)L^KSE`,:/XA?*C.)D^KSE`,:/XA?*C.)<^KSE`,:/
MXA?*C.)4^KSE`,:/XA?*C.),^KSE`,:/XA?*C.)$^KSE`,:/XA?*C.(\^KSE
M`,:/XA?*C.(T^KSE`,:/XA?*C.(L^KSE`,:/XA?*C.(D^KSE`,:/XA?*C.(<
M^KSE`,:/XA?*C.(4^KSE`,:/XA?*C.(,^KSE`,:/XA?*C.($^KSE`,:/XA?*
MC.+\^;SE`,:/XA?*C.+T^;SE`,:/XA?*C.+L^;SE`,:/XA?*C.+D^;SE`,:/
MXA?*C.+<^;SE`,:/XA?*C.+4^;SE`,:/XA?*C.+,^;SE`,:/XA?*C.+$^;SE
M`,:/XA?*C.*\^;SE`,:/XA?*C.*T^;SE`,:/XA?*C.*L^;SE`,:/XA?*C.*D
M^;SE`,:/XA?*C.*<^;SE`,:/XA?*C.*4^;SE`,:/XA?*C.*,^;SE`,:/XA?*
MC.*$^;SE`,:/XA?*C.)\^;SE`,:/XA?*C.)T^;SE`,:/XA?*C.)L^;SE`,:/
MXA?*C.)D^;SE`,:/XA?*C.)<^;SE`,:/XA?*C.)4^;SE`,:/XA?*C.),^;SE
M`,:/XA?*C.)$^;SE`,:/XA?*C.(\^;SE`,:/XA?*C.(T^;SE`,:/XA?*C.(L
M^;SE`,:/XA?*C.(D^;SE`,:/XA?*C.(<^;SE`,:/XA?*C.(4^;SE`,:/XA?*
MC.(,^;SE`,:/XA?*C.($^;SE`,:/XA?*C.+\^+SE`,:/XA?*C.+T^+SE`,:/
MXA?*C.+L^+SE,$`MZ2303>+D,9_E%`"-Y1`0C>4,((WE%`"-XA`0C>(,((WB
M`#"3Y1PPC>4`,*#CF/__Z[PAG^6\`9_E`A"@X8H+`.NT,9_E`%#3Y0``5>.L
M09\5"0``&FK__^ND(9_E``!0XPP`@N5?```*D$&?Y4/__^L``)3EW?__ZWU7
MP.4``)3EVO__ZP`PH.$``)3EQB/3Y0(@@N/&(\/EU/__ZQ10G>4$((7B!P%R
MXP-0A>+&,]#E`3"#X\8SP.5&``"*`@&@X57__^L\(9_E$!"=Y3!!G^44P)WE
M`0!<XP`PH.$$`)+E`""1Y00PA.4`((/E&"&?Y0@`@^4$((/E$"&?Y0P@@^4U
M``#:!`!!X@P!@.`,(:#A#,"#X@3@L>4``%'A!."LY?O__QH,P(+B`!"@XP`0
MC>4%(*#A#!"#YPP`E.70$)_E=___ZP!04.(2```*#`"4Y2+__^N\`)_E&!"-
MXFL``.L``%#C#P``"@P`E.4&___K9?__ZW0PG^4`()/E'#"=Y0(@,^``,*#C
M%0``&@4`H.$DT(WB,("]Z`P`E.5^___K`%"@X>C__^H(`)3E``!0XP$```H$
M!P#KZO__ZE@`G^48$(WB40``ZP``4.,(`(3EY/__"O;__^I@___K$,"@X]#_
M_^KQ_O_K`0"@XR+__^O@C0(`%!8!`(P6`0`8D`(`%)`"`"B0`@`(D`(`7$D!
M`&!)`0#0(`$`*$<!`,A&`0``L*#C`."@XP00G>0-(*#A!"`MY00`+>40P)_E
M!,`MY0P`G^4,,)_E__[_ZUO__^M\10$`$!<!`!Q%`0`4,)_E%""?Y0,PC^`"
M()/G``!2XQ[_+P'Z_O_J='4!``@!```8`)_E&#"?Y0``4^$>_R\!$#"?Y0``
M4^,>_R\!$_\OX1"0`@`0D`(``````"0`G^4D$)_E`#!!X*,?H.%#$8'@P1"P
MX1[_+P$0,)_E``!3XQ[_+P$3_R_A$)`"`!"0`@``````$$`MZ1A`G^4`,-3E
M``!3XQ"`O1C@___K`3"@XP`PQ.40@+WH))`"`.;__^KP1RWI`)!0XBH```JT
M,)_E`("3Y0``6.,H```*`%#9Y0%PH.$``%7C/0!5$P%0H!,`4*`#$0``&@!`
MF.4``%3C#```"@A@H.$$`*#A!2"@X0D0H.$2___K``!0XP(``!H%,-3G/0!3
MXPL```H$0+;E``!4X_/__QH$`*#A\(>]Z`E0H.$!,/7E``!3XST`4Q/[__\:
M"5!%X.;__^H(8$;@`5"%XD9AH.$%0(3@!`"@X0!@A^7PA[WH"4"@X>W__^H(
M0*#AZ___ZA"0`@!,,9_E\$$MZ0!04.)XT$WB`#"3Y70PC>4`,*#C`@``"@`P
MU>4``%/C!P``&B`QG^4`()/E=#"=Y0(@,^``,*#C0@``&GC0C>+P@;WH?O[_
MZP!`4.+T__\*^'"?Y00`H.'0_O_K``!0XRH```H3,-#E$V"`XBX`4^,"```:
M`3#6Y0``4^/T__\*$S#0Y2X`4^,E```*!0"@X8/^_^L`@*#A!@"@X8#^_^L`
M`(C@`@"`XFO^_^L',*#A`"#@XP$0H.,$8(WE`%"-Y0!@H.&%_O_K"""-X@80
MH.$#`*#CNO[_ZP$`<.,&`*#A`P``"A@PG>4/.@/B`0E3XQ(```HZ_O_K!@"@
MX1K^_^L$`*#AI?[_ZP``4./4__\:!`"@X;G^_^L%`*#A&_[_Z[___^H!,-;E
M+@!3X];__QH",-;E``!3X\7__PK2___JK/__Z^O__^H?_O_KX(T"`&A&`0`0
M0"WI<-!-XG@PG^4`$*#A`$"@X0T@H.$#`*#C`#"3Y6PPC>4`,*#CG/[_ZP``
M4.,``*`3!```&A`PG>4/.@/B"@I3XP$)4Q,'```*-#"?Y0`@D^5L,)WE`B`S
MX``PH.,'```:<-"-XA"`O>@"$*#C!`"@X6C^_^L0#V_AH`*@X?'__^K[_?_K
MX(T"`!!`+>D`0*#A+?[_ZP$P0.(#,(3@`P!4X0,@H#$#```Z)```Z@0`4N$"
M,*#A(0``"@(PH.$!$%+D+P!1X_C__PH#`%3A&P``*@$P0^(#`%3A&@``"@`@
MT^4O`%+C^?__&@$P0^(#``#J`!#3Y0$P0^(O`%'C`@``&@,`5.$#(*#A^/__
M.@0@0N`",(+B`0I3XP8``(H!.J#C`2""X@00H.$\`)_EROW_ZS0`G^40@+WH
M``"@XQ"`O>@#`%3AY___&@`PU.4O`%/C`@``"A!`O>@0`)_EP?W_ZA!`O>@(
M`)_EOOW_ZCB0`@!P1@$`.$8!`/!`+>D!VDWB#-!-X@$ZC>(!4*#AV!"?Y=@@
MG^4`$)'E!!"#Y0`0H.,`8*#A!!"-XL0`G^4$,(/BP?W_ZP#`4.(B``#:"#"-
MX@%`3.($X(/@!#!>Y0``4^.@,)_E`'"3Y1@``!H``%3C&@``"@0@H.$O$*#C
M!`"-X@7^_^L``%#C%```"@<`H.$K_O_K!#"@X00@C>(&$*#A#_[_ZP$ZC>),
M()_E!#"#X@`0DN4`()/E`1`RX``@H.,,```:`=J-X@S0C>+P@+WH#$"@X>;_
M_^HH,)_E`'"3Y0<`H.$6_O_K!2"@X080H.&2_?_KZO__ZH']_^O@C0(`_P\`
M`'1&`0`4D`(`\$<MZ0%`H.$`,-'EY"&?Y0C03>(]`%/C`4"!`@!0H.$$`*#A
M`""2Y00@C>4`(*#CIOW_ZPT0H.$`8*#A!0"@X<3^_^L`D%#B/0``"I_]_^L`
M`%;A-```F@!PG>68@9_E!W&@X0`PU>4``%/C/0!3$P$PH!,`,*`#!0``"@4P
MH.$!(//E``!2XST`4A/[__\:!3!#X`(`AN(#`(#@`&"8Y7C]_^L``%#C!P"&
MYQ8```H`$)WE`""8Y04`H.$!,-#D`1&2YP``4^,]`%,3`##!Y08```H!(('B
M`3#0Y`(0H.$]`%/C``!3$P$PPN3Y__\:`2"@X3TPH.,`,,'E`3#4Y```4^,!
M,.+E^___&N0PG^4`()/E!#"=Y0(@,^``,*#C,P``&@C0C>+PA[WH`9!)X@$P
MU.0``%/C`3#IY?O__QKQ___JL("?Y0!PF.4`,)?E``!3XR,```H',*#A!""S
MY0D0H.$``%+C`9")XOK__QH#$('B`1&@X8`PG^4`()/E``!2XP\``!H!(*#C
M`0"@X0`@@^4[_?_K`*!0XMK__PH'$*#A"7&@X0<@H.'V_/_K`*"(Y0$PB>(`
M(*#C`R&*YP"0C>6F___J!P"@X1+]_^L``%#C`*"@X0``B.7*__\*"7&@X?+_
M_^H#D*#A"!"@X^#__^K__/_KX(T"`!"0`@`HD`(`$$`MZ0C03>)$0)_E``"4
MY8?]_^L``)3EA?W_ZS0PG^4T()_E-!"?Y3S]_^L``)3E?_W_ZR@PG^4`P*#C
M)""?Y200G^4($(WH3/W_ZPC0C>(0@+WH%)`"`.2$`0!\%`$`A$8!`%A)`0",
M,@$`H$8!`!PPG^400"WI``"3Y6S]_^L00+WH##"?Y0P@G^4,$)_E(OW_ZA20
M`@#DA`$`?!0!`(1&`0`P0"WI`MI-XAS03>*L()_E`CJ-XA0P@^(`()+E`""#
MY0`@H./Y_/_KE!"?Y90PG^64()_E\`#-X0$0H.,,`(WB!_W_ZP$:C>(!*J#C
M$!"!X@P`C>+/_/_K`$!0X@!0H+,)``"Z`0"$XMS\_^L`4%#B!0``"@$:C>($
M(*#A$!"!XIW\_^L`,*#C!##%YP(ZC>(H()_E%#"#X@`0DN4`()/E`1`RX``@
MH.,#```:!0"@X0+:C>(<T(WB,("]Z*/\_^O@C0(`Q$8!`+A&`0`!$```RO__
MZO!/+>E"W4WB!-!-XO@AG^5!/8WB`%"@X0%@H.'L`9_E$!"-XCPP@^(`()+E
M`""#Y0`@H./H_?_K+Q"@XP!`H.$%`*#AR/S_ZP``4.,.```*O`&?Y040H.$)
M___K!0"@X4$]C>*@(9_E/#"#X@`0DN4`()/E`1`RX``@H.-A```:0MV-X@30
MC>+PC[WH!0"@X:_\_^M\$9_E`("@X08`H.'D_/_K`*!0XNC__PH`,-KE9)&?
MY5QQG^4``%/C?&"-XCD```H``%3C!```"@H0H.$$`*#A0?S_ZP``4.,I```*
M"@"@X9K\_^L!$$#B`."@X0$PVN<O`%/C`3"*X`H``!H"`$#B``"*X`,00>`#
M`$#@`R"@X0"PH.,!X(/@`+##Y@'`<N4O`%SC^O__"@$PB.(.X(/@`0I>X\3_
M_ZK<()_E"3"@X0$0H.,$((WE!@"@X0$JH.,(4(WE`*"-Y8O\_^L0((WB!A"@
MX0,`H./`_/_K``!0XP,``!H@,)WE#SH#X@()4^,4```*!Q"@X0``H..H_/_K
M``!0XP"@H.&K__\*`##:Y0``4^/%__\:``!4XP(```H`,-3E+@!3XP(```I<
MH)_E`>"@X]?__^H!,-3E``!3X^O__PKX___J`1"@XP8`H.&-_/_K``!0X^7_
M_QH<`)_E!A"@X:'^_^L&`*#A&OS_ZY7__^H;_/_KX(T"`,A&`0#41@$`Y$8!
M`.A&`0!P1@$`.$8!```PT.4``%/C'O\O`0$@@.(O`%/C`@"@`0$PTN0``%/C
M^O__&A[_+^$`,%#B`P``"@`PT^4``%/C````"@G^_^H``)_E__O_ZCA&`0`P
M0"WI--!-XF3DG^5D-)_E","-X@`PD^4L,(WE`#"@XP\`ONA01)_E4%2?Y0\`
MK.@/`+[H#P"LZ``PGN6P,,SA!!"-X@0`H.%&_?_K``!0XPP```H$$)WE`""5
MY0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J
M]$.?Y>Q3G^4$$(WB!`"@X3+]_^L``%#C#```"@00G>4`()7E`3&"X`0`D^4`
M`%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^JH0Y_EG%.?Y000
MC>($`*#A'OW_ZP``4.,,```*!!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___
M"@0P@^($()/E``!2XP0@@^3[__\:[?__ZEQ#G^5,4Y_E!!"-X@0`H.$*_?_K
M``!0XPP```H$$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4`
M`%+C!""#Y/O__QKM___J$$.?Y?Q2G^4$$(WB!`"@X?;\_^L``%#C#```"@00
MG>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___
M&NW__^K$0I_EK%*?Y000C>($`*#AXOS_ZP``4.,,```*!!"=Y0`@E>4!,8+@
M!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:[?__ZGA"G^5<
M4I_E!!"-X@0`H.'._/_K``!0XPP```H$$)WE`""5Y0$Q@N`$`)/E``!0XP$!
M@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J+$*?Y0Q2G^4$$(WB!`"@
MX;K\_^L``%#C#```"@00G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B
M!""3Y0``4N,$((/D^___&NW__^K@09_EO%&?Y000C>($`*#AIOS_ZP``4.,,
M```*!!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@
M@^3[__\:[?__ZI1!G^5L49_E!!"-X@0`H.&2_/_K``!0XPP```H$$)WE`""5
MY0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J
M2$&?Y1Q1G^4$$(WB!`"@X7[\_^L``%#C#```"@00G>4`()7E`3&"X`0`D^4`
M`%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^H$$(WB^`"?Y6S\
M_^L`$%#B`0``"MP`G^62_?_K!!"-XN``G^5E_/_K`!!0X@$```K4`)_EB_W_
MZP00C>+,`)_E7OS_ZP`04.(,```*G`"?Y83]_^NX$)_EB`"?Y8']_^MH,)_E
M`""3Y2PPG>4"(#/@`#"@XQ,``!HTT(WB,("]Z`00C>*,`)_E3/S_ZP`04.("
M```*6`"?Y7+]_^OL___J=!"?Y0H@H.,9`(WB;/O_ZP``4./F__\:-`"?Y2,0
MC>)H_?_KXO__ZN3Z_^OPA`$`X(T"`/!&`0`0D`(`_$8!``1'`0`01P$`&$<!
M`"A'`0#(1@$`-$<!`$!'`0!,1P$`U$8!`%A'`0!L1P$`/$8!`(!'`0"P1P$`
MD$<!`*1'`0`00"WI"-!-XFQ`G^5L,)_E``"4Y0`PD^4$,(WE`#"@XP$`<.,'
M```*4#"?Y0`@D^4$,)WE`B`SX``PH.,-```:"-"-XA"`O>@T`)_E#1"@X1+\
M_^L``%#C!```"@``T.4P`%#C``!0$P$`H!,``*`#``"$Y>O__^JP^O_K")`"
M`."-`@`T1P$`$$`MZ8WZ_^N&^O_K``!0XP``D!40@+WH<$`MZ1C03>+L,)_E
M`%"@X1`0C>+D`)_E`#"3Y10PC>4`,*#C]?O_ZP!`4.(.```*`##4Y0``4^,+
M```*!1"@X6SZ_^L``%#C$@``"J@PG^4`()/E%#"=Y0(@,^``,*#C)```&AC0
MC>)P@+WHB#"?Y0`@D^44,)WE`B`SX``PH.,%$*`!=`"?!1H``!H8T(WB<$"]
MZ`/]_^H%`*#AM?K_ZP!@H.$$`*#ALOK_ZP``AN`"`(#BG?K_ZT0PG^4`(.#C
M`1"@XQ@`C>D`4(WE-#"?Y0!`H.&V^O_K'#"?Y0`@D^44,)WE`B`SX``PH.,$
M$*`!"`"?!>3__PIH^O_KX(T"`+1'`0#D1@$`Z$8!`/!/+>D"V4WB_-!-XO`V
MG^7P%I_E`BF-X@`0D>7T$(+E`!"@X_0@@N(`<*#A!P"3Z(1`C>(,X(/B)%"#
MX@<`A.B<P(WB#P"^Z)!`C>(/`*SH`P">Z`,`C.@'`)7H!P"$Z!@0C>*@!I_E
MH?O_ZP!`4.("```*`##4Y0``4^,$`0`:)?K_ZQ[Z_^L`0%#BW0``"@!0E.4`
M`%7CV0``"@4`H.%Q^O_K@`"@X0$`@.)<^O_K`"#5Y0``4N,`8*#A"P``"DB&
MG^4&0*#A!`"@X0`@C>4(,*#A`"#@XP$0H.-Q^O_K`2#UY0)`A.(``%+C]?__
M&AP&G^6@4(WB`@``Z@0`E>0``%#C#0``"A@0C>)X^__K`$!0XOC__PH`,-3E
M``!3X_7__PK\^__K``!0X_+__PH$`*#A$_K_ZP!`4.(4```:`%"@XX20C>+X
M,(WB!3&#X'1`$^4``%3C#```"@&`A>((@8G@`##4Y0``4^,'```*!`"@X>C[
M_^L!4(7B``!0XSL``!H$0)CD``!4X_3__QH`0*#C!`"@X3/Z_^MTE9_E`*"@
MX08`H.$O^O_K``"*X`&K@.($H(KB"@"@X1CZ_^M4-9_E`"#@XP$0H.,(,(WE
M#&"-Y40UG^4`0(WE!)"-Y0"`H.$O^O_K!QV@XP@`H.$U^O_K`0!PXP,``!HF
M^O_K`!"0Y1$`4>.7```:&""-X@@0H.$#`*#C9_K_ZP!04.(8```*^!2?Y0`P
ME^7T))_E``"1Y0$0H.,`@(WE-/K_ZP!@H.,".8WBN"2?Y?0P@^(`$)+E`""3
MY0$0,N``(*#C)@$`&@8`H.$"V8WB_-"-XO"/O>@$`*#APOG_ZP!`4.*P__\*
MPO__ZB@PG>4/.@/B`0E3X^+__QHP0)WEGOG_ZP``5.'>__\:*#"=Y8,[H.&C
M.Z#A!PU3X]G__QH*`*#AU_G_ZQ@0C>(`8*#A6`2?Y0?[_^L``%#C@0``"@!`
ME^6H^?_K`!"@X00`H.$)_?_K`*!0XGH```H*`*#AVOG_ZP,`4.,`0*#A"P``
MF@0`0.(8%)_E``"*X';Y_^L``%#C!0``&@0`5./%```*!$"*X`4P5.4O`%/C
MP0``"O!#G^4`,)3E`0!SXV<```H``%/C=```"MP3G^7<`Y_E#OS_Z[OY_^O4
M<Y_EU#.?Y0`@X.,!$*#C\(#-X0QPC>7$HY_E"`"-Y08`H.'&^?_K#@``ZL'Y
M_^L`,)#E$0!3XQ```!JK^?_K`5"%X@HPH.$$(*#A`1"@XQ!PC>4,4(WE`,"@
MX08`H.$`$XWHMOG_ZP<=H.,&`*#AO/G_ZP$`<.,`0*#AZO__"@@`H.%1^?_K
M&`.?Y080H.'H^__K!@"@X;S^_^N/___J!4"@X9!@C>+X,(WB!#&#X&@`$^4`
M`%#C*@``"@%0A.(%@8;@`P``Z@0`F.0``%#C)```"@%0A>(8$(WBJ_K_ZP5`
MH.$`,%#B]O__"@`PT^4``%/C\___"DGY_^L`4%#B#/__&N?__^JP`I_E`#"7
MY=`BG^4``)#E!!"-Y0"`C>4!$*#CH?G_ZP!@H.-K___JEO[_ZP(YC>)D(I_E
M]#"#X@`0DN4`()/E`1`RX``@H..1```:!`"@X0+9C>+\T(WB\$^]Z"[Y_^H-
M`*#C4_G_ZW12G^53(*#C`&"@X?;^_^H`H)?E@O__ZD@"G^48$(WB?OK_ZP``
M4.,``(0%"```"@`PT.4``%/C,`!3$P$PH!,`,*`#`3"@$P`PA`4`,(05BO__
M&@H`H.$`$*#C./G_ZP!`4.*%__\*`E"@XP`PX.,1(.#C`%"-Y2CY_^L&(*#C
M]!"-X@0`H.'K^/_K]##=Y0``4^,"```:]3#=Y4,`4^-````*`#"@XP`@H.,`
M,(WE!`"@X0`PH.,8^?_K500`ZP!0H.$"``#J]!"-X@4`H.%O!`#K`BF@X_00
MC>($`*#AU?C_ZP`@4.+V___*!`"@X7GY_^L%$*#AM`"-XK0$`.OX,(WB,*!#
MXBRQG^6S4(WB"D"@X3%P0^(!(/7E!`"@X0LPH.$`((WE`1"@XP`@X.,G^?_K
M!0!7X0)`A.+U__\:)"&?Y0`0H.,,((WE\!#-Y2@QG^4`(.#C`1"@XP8`H.$(
MH(WE\(#-X1GY_^MG___J!$"7Y0``5.,Z__\*!`"@X03Y_^L#`%#C-O__F@0`
M0.+L$)_E``"$X*'X_^L``%#C!*"@`2___^KV,-WE00!3X[O__QKW,-WE0P!3
MX[C__QKX,-WE2`!3X[7__QKY,-WE10!3X[+__QH`,.#C!`"@X3D@X.,`4(WE
MS/C_Z_00C>($`*#A*2"@XX_X_^MH()_E]#"-X@@PC>4,((WE;#"?Y0`@X.,!
M$*#C!@"@X020C>4`@(WEZOC_ZSC__^JC^/_K%(4!`."-`@#(1@$`S$<!`#Q&
M`0!P1@$`X$<!`-1'`0`@D`(`)$@!`'A(`0"`2`$`")`"`+!'`0`T1P$`6$D!
M`*!(`0"P2`$`Z$<!`,1'`0"02`$`B$@!`'!`+>D(T$WB$$*?Y1`RG^4``)3E
M`#"3Y00PC>4`,*#C%/G_ZP!0H.$``)3E$?G_ZV@@U>4-$*#A`#"@X>0!G^5I
M(,/ET_G_ZP``4.,"```*`##0Y3$`4^-7```*<_S_ZP``E.4#^?_KO!&?Y0,P
MH.,!(*#CF?C_ZP!04.(*```*``"4Y?OX_^L0,)7EG"&?Y0`0D^5V^/_K$#"5
MY0`PD^4(,)/E`043XU```!H``)3E\/C_ZW@1G^4#,*#C`2"@XX;X_^L`4%#B
M"@``"F0!G^4-$*#AK_G_ZP!@4.(Z```*``"4Y>/X_^L0,)7E!B"@X0`0D^5>
M^/_K/&&?Y0``E.7<^/_K`%"@X0``E.79^/_K*!&?Y0$@H..%^/_K("&?Y0`0
MH.$%`*#A4?C_ZP``E.70^/_K`""@XPT0H.$`,*#A``&?Y6D@P^62^?_K``!0
MXP!`H.$(`(;E#P``"@<=H.,$`*#A@?C_ZP$@@.(1`%#C`0!2$P`PH.$C``"*
MH#"?Y0`@D^4$,)WE`B`SX``PH.,<```:"-"-XG"`O>@$`);EO_W_ZP``4.,`
M0*#A"`"&Y>G__QJ0`)_E9OC_ZP$PT.4``%/CI?__"J/__^IH8)_E``"4Y:?X
M_^L$();E$#"5Y0`0DN4``)/E4_K_Z\+__^H``)3EG_C_ZQ`PE>4`$)/E9OC_
MZZC__^H*^/_K!""6Y3@`G^4`$)+E!""@X4WX_^L4D`(`X(T"`!A'`0#$2`$`
MR$@!`-!(`0#41@$`*)`"`-1(`0#L2`$`R$8!`/1(`0`820$`/#&?Y?!`+>D`
M<%#B#-!-X@`PD^4$,(WE`#"@XS,```H`,-?E``!3XS````KQ^?_K`$"@X0`P
MU.4``%/C!0``"@$@A.(O`%/C`D"@`0$PTN0``%/C^O__&NA@G^4`4%?B`5"@
M$P`PEN4!`'/C(P``"@``4^,`4*`#`5`%$@``5>,'```:N#"?Y0`@D^4$,)WE
M`B`SX``PH.,H```:#-"-XO"`O>@`,-?E``!3X_3__PJ4$)_E!""@XP0`H.%)
M^/_K``!0X^[__QIT,)_E`""3Y00PG>4"(#/@`#"@XQ<``!H'`*#A#-"-XO!`
MO>A'^?_J6`"?Y;?W_^L`0*#AS/__ZDP`G^4-$*#A#?G_ZP``4.,``(8%VO__
M"@`PT.4``%/C,`!3$P`PH`,!,*`3`#"&!=/__PH!,*#C`#"&Y<[__^JG]__K
MX(T"``B0`@#@1P$`.$8!`#1'`0#(.Y_E\$\MZ:/?3>)`$(#B@&"`X@T@H.$`
M,)/EA#*-Y0`PH.,`4*#C!,`1Y0C@$>4($('B+#2@X?\\`^(L/(/A#$2@X0P\
M@^'_2`3B/L^_Y@0P@^$&`%'A`,""Y010@N4(,(+E#%""Y1`@@N+M__\:",!-
MXG[OC>(`,*#C#$"@X0A@O.5P()3E2)"4Y700E.5,@)3E&'"4Y1Q0E.4)("+@
M!$"<Y0@0(>`'("+@!B`BX`40(>`$$"'@HD^@X8%`A.$"()+@!"""X0X`7.'P
M*,SAZ?__&O@JG^4`4)#E`!"=Y02@D.4@P)#E`A"1X`P0D>"ES:#A$$"0Y0AP
MD.488)#EBL*,X0R0D.6%PHSA`<"<X`80).`GX:#A!Q`!X`GOCN$&$"'@`<"<
MX`>/CN$($)WE".`DX`(0D>`ED:#A!>`.X`3@+N`&$)'@"I^)X06?B>$.$)'@
M$."=Y0F@*.`"X)[@#*`*X`3@GN`(H"K@"J">X!C@G>7L'8'@`N">X`C@GN!L
M@2G@`8`(X`F`*.`(@)[@(."=Y>&MBN`"X)[@81&@X0F0GN!LX2'@"N`.X&SA
M+N`.D)G@*."=Y>J-B.`"X)[@;,&.X&KA(>`(X`[@`>`NX`[`G.`PX)WEZ)V)
MX`+@GN!H@:#A`1">X&KA*.`)X`[@Z<V,X&KA+N`.$)'@[.V!X#@0G>4"$)'@
M:A&!X&FA*.`,H`K@"*`JX`H0D>!`H)WE;,&@X0*@FN`(@)K@::$LX`Z@"N#N
M'8'@::$JX`J`F.#AK8C@2("=Y0*`F.!I@8C@;I$LX`&0">`,D"G@"8"8X%"0
MG>5A$:#A`I"9X`S`F>!ND2'@"I`)X.J-B.!ND2G@"<"<X.B=C.!8P)WE`L"<
MX&[!C.!JX2'@".`.X`'@+N`.P)S@8."=Y6B!H.$"X)[@`1">X&KA*.`)X`[@
MZ<V,X&KA+N`.$)'@[.V!X&@0G>4"$)'@:A&!X&FA*.`,H`K@"*`JX`H0D>!P
MH)WE;,&@X0*@FN`(@)K@::$LX`Z@"N#N'8'@::$JX`J`F.#AO8C@>("=Y:"@
MG>4"@)C@:8&(X&Z1+.`!D`G@#)`IX`F0F."`@)WE81&@X0*`F.`,P)C@;H$A
MX`N`".#KG8G@;H$HX`C`G.#IC8S@B,"=Y0+`G.!NP8S@:^$AX`G@#N`!X"[@
M#L"<X)#@G>5ID:#A`N">X`$0GN!KX2G@".`.X.C-C.!KX2[@#A"1X.SM@>"8
M$)WE`B"1X&NQ@N!H(2G@#"`"X`D@(N`"L)O@&"B?Y6S!H.$"H)K@[AV+X`F@
MFN"HL)WE:)$LX`Z0*>`)D)K@`K";X&BQB^"PH)WE;H$LX`&`*.#AG8G@"(";
MX&$1H.$"H)K@#*":X+BPG>5NP2'@Z8V(X`G`+.`,P)K@`K";X.BMC.!NX8O@
M:<$AX,"PG>4(P"S@#.">X&B!H.$"L)O@R,"=Y0&PF^!I$2C@ZNV.X`H0(>`!
M$)O@`L"<X.Z]@>!ID8S@:A$HX-#`G>4.$"'@`9"9X&[AH.$"P)S@V!"=Y0B`
MG.!JP2[@"\`LX`R`F.`"$)'@ZYV)X.#`G>5JH8'@:Q$NX`D0(>#IC8C@`:":
MX&F1H.$"P)S@Z!"=Y0[@G.!KP2G@",`LX`S@GN`"$)'@Z*V*X/#`G>5KL8'@
M:!$IX`H0(>#J[8[@`;";X&JAH.$"P)S@^!"=Y0F0G.!HP2K@#L`LX`R0F>`"
M$)'@[KV+X&B!@>!N$2K@"Q`AX`&`F.``$9WEZYV)X`(0D>!KL:#A;L$KX`J@
MD>`($9WE"<`LX`R@FN`"$)'@Z8V(X!#!G>5NX8'@:1$KX`@0(>#HK8K@`>">
MX&B!H.$"P)S@&!&=Y0NPG.!IP2C@ZNV.X`K`+.`,L)O@`A"1X&K!*.!I$8'@
M[IV+X""QG>4.P"S@#!"1X&[AH.$"L)O@Z<V!X`B`F^!J$2[@*+&=Y0D0(>`!
M$)C@`K";X&JAB^!I@2[@,+&=Y>P=@>`,@"C@"(":X&RAH.$"L)O@X<V(X`[@
MF^!I@2K@.+&=Y0&`*.`(X)[@`B";X&F1@N!A(2K@#"`BX.R-CN`"D)G@0.&=
MY<`EG^5LP:#A`N">X`K@GN!AH8SA8;$,X`B@"N`+H(KA"N">X$BAG>7HG8G@
M`K":X&BAC.'I[8[@8;&+X`F@"N!I$:#A:)$,X`F0BN%0H9WE"Y"9X`*@FN`,
MP)K@:*&!X6BQ`>`.H`K@"Z"*X0S`FN!8H9WE[IV)X`*PFN!NH8'A:+&+X`F@
M"N#IC8S@:<&@X6Z1`>`)D(KA8*&=Y0N0F>`"H)K@`1":X&ZAC.%NL0S@"*`*
MX`N@BN$!H)K@:!&=Y>B=B>`"L)'@:!&,X>FMBN!NL8O@"1`!X&GAH.%HD0S@
M"1"!X7"1G>4+$)'@`I"9X`S`F>!HD8[A:+$.X`J0">`+D(GA#)"9X'C!G>7J
M'8'@`K"<X&BQB^!J@8[AX9V)X&'!H.$!@`C@:A$.X`$0B.$+$)'@Z;V!X(`1
MG>5J@0S@`A"1X`X0D>!JX8SA">`.X`C@CN$!X)[@B!&=Y>N-CN`"$)'@:J&!
MX&D1C.%KX:#A"Q`!X&FQ#.`+$('A"J"1X)`1G>5IL0[@`A"1X`P0D>#HS8K@
M::&.X0B@"N`+H(KA`:":X)@1G>5HL0[@`A"1X&F1@>!H$8[A#!`!X.RMBN`+
M$('A"1"1X.J]@>"@$9WE;,&@X0(0D>`.$)'@:.&,X6B1#.`*X`[@">".X0&0
MGN"H$9WEZYV)X`+@D>!J$8SA:.&.X`L0`>!K@:#A:K$,X`L0@>$.X)'@L!&=
MY6JQ".`"$)'@#!"1X.G-CN!JX8CA">`.X`O@CN$!$)[@N.&=Y6FQ".`"X)[@
M:N&.X.RM@>!I$8CA#!`!X`L0@>$.X)'@P!&=Y6S!H.$"$)'@"!"1X&F!C.%I
ML0S@"H`(X`N`B.$$,(#E`8"8X,@1G>7J[8[@`A"1X&F1@>!J$8SA:K$,X`X0
M`>`+$('A"9"1X-`1G>7NC8C@`A"1X&[AH.$,$)'@:L&.X6JQ#N`(P`S@"\",
MX0'`G.#8$9WEZ)V)X`(@D>!H$8[A:+$.X`D0`>!JH8+@"Q"!X=`BG^4*$)'@
MX*&=Y>G-C.`"H)K@:9&@X>BQG>4.X)K@[*V!X&@1*>`,$"'@`>">X`*PF^!L
M$2G@:(&+X/"QG>4*$"'@ZNV.X`&`F.!JH:#A`K";X`FPF^#X$9WE;)$JX`Z0
M*>`)D)O@`A"1X.Z-B.``LIWE;,&!X&X1*N`($"'@Z)V)X`'`G.!H@:#A`K";
MX`JPF^`($IWE;J$HX`F@*N`*H)O@`A"1X.G-C.`0LIWE;N&!X&D1*.`,$"'@
M[*V*X`'@GN!LP:#A`K";X`BPF^`8$IWE:8$LX`J`*.`(@)O@`A"1X.KMCN`@
MLIWE:9&!X&H1+.`.$"'@[HV(X`&0F>!NX:#A`K";X`RPF^`H$IWE:L$NX`C`
M+.`,P)O@`A"1X.B=B>`PLIWE:J&!X&@1+N`)$"'@Z<V,X`&@FN!ID:#A`K";
MX`ZPF^`X$IWE:.$IX`S@+N`.X)O@`A"1X.RMBN!`LIWE:(&!X&P1*>`*$"'@
MZNV.X`&`F.!JH:#A`K";X`FPF^!($IWE;)$JX`Z0*>`)D)O@`A"1X.Z-B.!0
MLIWE;,&!X&X1*N`($"'@Z)V)X`'`G.!H@:#A`K";X`JPF^!8$IWE;J$HX`F@
M*N`*H)O@`A"1X.G-C.!@LIWE;N&!X&D1*.`,$"'@[*V*X`'@GN!LP:#A`K";
MX`BPF^!I@2S@ZNV.X`J`*.`(@)O@[HV(X&@2G>5H88;@`A"1X&F1@>`88(#E
M<!*=Y6IA+.`.8";@!I"9X`(0D>`,$)'@Z,V)X&[AH.%L083@:F$NX!!`@.5X
M0IWE"&`FX`80D>`"()3@!2"2X&JA@N!H(2[@[!V!X`P@(N`@P)#E`J":X.$M
MBN`'$)'@#.">X`PP@.44,(#E'#"`Y0`@@.4($(#E(."`Y20P@.4<,)_E`""3
MY80RG>4"(#/@`#"@XP$``!JCWXWB\(^]Z*[T_^O@C0(`F7F"6J'KV6[<O!N/
MUL%BRA!`+>F``*#CRO3_ZPY[G^T`(*#C`'N`[0U[G^UX((#E`GN`[0Q[G^T$
M>X#M#'N?[09[@.T,>Y_M"'N`[0Q[G^T*>X#M#'N`[1"`O>@!(T5G`````(FK
MS>\`````_MRZF`````!V5#(0`````/#ATL,```````````````#P1RWI`I"@
MX2@PD.4L()#EB>&#X`,`7N$`P*#C`C#<X`!0H.$P()#E`4"@X300D.7)#Z#A
M`@``*@$PDN(#(*#A`!"AXJD^H.&`,8/A`C"3X*`>H>!X`)7E.("%X@``4.,H
MX(7E+,"%Y3`PA>4T$(7E'P``&C\`6>,N``#:0)!)XBECH.$!<(;B!W.$X`@P
MH.%`X(3B`,"4Y00`E.4($)3E#""4Y1!`A.(.`%3A`,"#Y00`@^4($(/E#""#
MY1`P@^+S__\:!0"@X;3\_^L'`%3A[?__&@9M9N`&DXG@"2"@X0<0H.$(`*#A
M.O3_ZWB0A>7PA[WH0'!@X@<`6>$)<*"Q``"(X`<@H.$$$*#A,?3_ZW@PE>4#
M,(?@0`!3XW@PA>7PA[T8!0"@X0>02>`'0(3@FOS_Z\[__^H$<*#AYO__ZO!!
M+>DX<('B*""1Y3!@D>4RC[_FHC&@X3\P`^(!((/B`4"@X3@`4N-_$.#C`%"@
MX39OO^8"`(?@`Q#'YSP``-I`(&+B`!"@XWCT_^L$`*#A@OS_ZP<`H.$X(*#C
M`!"@XW+T_^L$`*#A<&"$Y72`A.5Z_/_K`S#4Y00`H.$`,,7ELC#4X0$PQ>4`
M,)3E(S2@X0(PQ>4`,)3E`S#%Y0LPU.4$,,7ENC#4X04PQ>4(,)3E(S2@X08P
MQ>4(,)3E!S#%Y1,PU.4(,,7ELC'4X0DPQ>40,)3E(S2@X0HPQ>40,)3E"S#%
MY1LPU.4,,,7ENC'4X0TPQ>48,)3E(S2@X0XPQ>48,)3E#S#%Y2,PU.40,,7E
MLC+4X1$PQ>4@,)3E(S2@X1(PQ>4@,)3E$S#%Y?!!O>C5\__J."!BX@`0H.,[
M]/_KQ___ZO!'+>D`<*#A2&"?Y4A0G^4&8(_@!5"/X`5@1N`!@*#A`I"@X:WS
M_^M&8;#A\(>]"`!`H.,$,)7D"2"@X0@0H.$'`*#A`4"$XC/_+^$$`%;A]___
M&O"'O>BH2`$`H$@!`![_+^$(,)_E`S"/X``PD^7/\__J>$H!``A`+>D(@+WH
M`0`"`#H````]````"@```#T````/````/0```"0````]````,@```#T````"
M````/0````4````]````$P```#T````-````/0````P````]````(P```#T`
M```1````/0```"8````]`````0```#T````7````/0````@````]````"0``
M`#T``````````````"]T;7``````+@```%!!4E]435!$25(``%1%35!$25(`
M5$U0`%5315(`````55-%4DY!344`````)7,O)7,````O````+W!R;V,O<V5L
M9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z
M.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`4$%27U1%35``````4$%2
M7U!23T=.04U%`````#H````E<R5S)7,``%!%4DPU3$E"`````%!%4DQ,24(`
M4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,
M3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3CT``#$```!,1%],
M24)205)97U!!5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O
M<&5R871I;VXI"@``4$%42`````!P87)L`````"YP87(`````)7,E<V-A8VAE
M+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````!@`
M``!P97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U,@``
M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H`````+64``"TM``!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#
M+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]
M("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E
M("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL
M96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H
M<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD
M4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N
M=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&
M2"P@)SPZ<F%W)RP@)'!R;V=N86UE(&]R(&QA<W0["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R
M-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2![
M"B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C
M:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@
M96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H
M:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L
M(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%2
M7TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U
M9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5
M;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS
M:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%
M3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A
M<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N
M86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*
M)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@
M/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B
M=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U
M;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*
M;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R
M971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H
M*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F
M:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`
M24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&
M:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER
M95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL
M96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_
M)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA
M;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*
M?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U
M;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@
M;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A
M8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@
M)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@
M9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D
M<&%R(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L
M("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N
M;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T
M95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C
M<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I
M('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@
M;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[
M"FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*
M;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E
M<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL
M96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S
M92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A
M<R`B)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO
M<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]
M"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H
M95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^
M8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ
M<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(ETI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@
M)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D
M(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*
M;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M
M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@
M>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@
M:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO
M9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU
M;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN
M86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O<B!D
M:64@<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@)&9H
M("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE
M(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M
M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*
M?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!2
M3T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD
M<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG
M>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF
M("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI]
M(&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H
M(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@
M>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/
M0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@
M,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@
M>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F
M:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET
M7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE
M9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y=
M"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI
M="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``
M<&5R;'AS:2YC````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``
M````,$8!`#A&`0``````/$8!`$!&`0!(1@$`S$8!`%!&`0``````5$8!`%Q&
M`0``````.@```#T````*````/0````\````]````)````#T````R````/0``
M``(````]````!0```#T````3````/0````T````]````#````#T````C````
M/0```!$````]````)@```#T````!````/0```!<````]````"````#T````)
M````/0``````````````8)/_?P$`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(!H!
M`/@9`0```````0```!D#```!````*0,```$````Y`P```0```$,#```,````
M_!,!``T```"410$`&0```-B-`@`;````!````!H```#<C0(`'`````0```#U
M_O]OM`$!``4```#8"P$`!@```%@%`0`*````RP0```L````0````%0``````
M```#````](X"``(```#X`0``%````!$````7````!!(!`!$```#4$0$`$@``
M`#`````3````"````!X````(````^___;P$```#^__]O=!$!`/___V\#````
M\/__;Z00`0``````````````````````````````````````````````````
M``````````````#DC0(````````````(%`$`"!0!``@4`0`(%`$`"!0!``@4
M`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!
M``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`
M"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(
M%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4
M`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!
M``@4`0````````````````#_____9$D!`$=#0SH@*%)A<W!B:6%N(#$P+C(N
M,2TV*W)P:3$I(#$P+C(N,2`R,#(Q,#$Q,`!!+@```&%E86)I``$D````!38`
M!@8(`0D!"@(2!!,!%`$5`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`+FEN=&5R
M<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N
M<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!
M4DTN97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD
M871A+G)E;"YR;P`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`
M+D%232YA='1R:6)U=&5S````````````````````````````````````````
M````````````````"P````$````"````5`$!`%0!```9```````````````!
M`````````!,````'`````@```'`!`0!P`0``)```````````````!```````
M```F````!P````(```"4`0$`E`$``"````````````````0`````````-```
M`/;__V\"````M`$!`+0!``"D`P``!0`````````$````!````#X````+````
M`@```%@%`0!8!0``@`8```8````!````!````!````!&`````P````(```#8
M"P$`V`L``,L$``````````````$`````````3@```/___V\"````I!`!`*00
M``#0````!0`````````"`````@```%L```#^__]O`@```'01`0!T$0``8```
M``8````#````!`````````!J````"0````(```#4$0$`U!$``#`````%````
M``````0````(````<P````D```!"````!!(!``02``#X`0``!0```!8````$
M````"````'P````!````!@```/P3`0#\$P``#```````````````!```````
M``!W`````0````8````(%`$`"!0```@#``````````````0````$````@@``
M``$````&````$!<!`!`7``"$+@`````````````(`````````(@````!````
M!@```)1%`0"410``"```````````````!`````````".`````0````(```"<
M10$`G$4``#A```````````````0`````````E@````$``'""````U(4!`-2%
M```(````#0`````````$`````````*$````!`````@```-R%`0#<A0``!```
M````````````!`````````"K````#@````,```#8C0(`V(T```0`````````
M``````0````$````MP````\````#````W(T"`-R-```$```````````````$
M````!````,,````!`````P```."-`@#@C0``!```````````````!```````
M``#0````!@````,```#DC0(`Y(T``!`!```&``````````0````(````V0``
M``$````#````](X"`/2.```,`0`````````````$````!````-X````!````
M`P````"0`@``D```$```````````````!`````````#D````"`````,````0
MD`(`$)```"@0``````````````@`````````Z0````$````P`````````!"0
M```N```````````````!`````0```/(````#``!P```````````^D```+P``
M`````````````0`````````!`````P``````````````;9````(!````````
,``````$`````````
